==> monodevelop_5.5.0.227.orig.tar.bz2: monodevelop-5.5/src/addins/VersionControl/MonoDevelop.VersionControl.Git/MonoDevelop.VersionControl.Git/GitCommitDialogExtensionWidget.cs <==
// 
// GitCommitDialogExtensionWidget.cs
//  
// Author:
//       Lluis Sanchez Gual <lluis@novell.com>
// 
// Copyright (c) 2011 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;

namespace MonoDevelop.VersionControl.Git
{
	[System.ComponentModel.ToolboxItem(true)]
	partial class GitCommitDialogExtensionWidget : Gtk.Bin
	{
		public GitCommitDialogExtensionWidget ()
		{
			this.Build ();
		}
		
		public bool PushAfterCommit {
			get { return checkPush.Active; }
		}
		
		public bool CommitterIsAuthor {
			get { return !checkAuthor.Active; }
		}
		
		public string AuthorName {
			get { return entryName.Text; }
		}
		
		public string AuthorMail {
			get { return entryEmail.Text; }
		}

		protected void OnCheckAuthorToggled (object sender, System.EventArgs e)
		{
			authorBox.Visible = checkAuthor.Active;
			OnChanged (sender, e);
		}
		
		void OnChanged (object sender, System.EventArgs e)
		{
			if (Changed != null)
				Changed (this, EventArgs.Empty);
		}
		
		public event EventHandler Changed;

	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/addins/VersionControl/MonoDevelop.VersionControl.Git/MonoDevelop.VersionControl.Git/GitCommitDialogExtensionWidget.cs <==
//
// GitCommitDialogExtensionWidget.cs
//
// Author:
//       Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2011 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;

namespace MonoDevelop.VersionControl.Git
{
	[System.ComponentModel.ToolboxItem(true)]
	partial class GitCommitDialogExtensionWidget : Gtk.Bin
	{
		public GitCommitDialogExtensionWidget ()
		{
			this.Build ();
		}

		public bool PushAfterCommit {
			get { return checkPush.Active; }
		}

		public bool CommitterIsAuthor {
			get { return !checkAuthor.Active; }
		}

		public string AuthorName {
			get { return entryName.Text; }
		}

		public string AuthorMail {
			get { return entryEmail.Text; }
		}

		protected void OnCheckAuthorToggled (object sender, EventArgs e)
		{
			authorBox.Visible = checkAuthor.Active;
			OnChanged (sender, e);
		}

		void OnChanged (object sender, EventArgs e)
		{
			if (Changed != null)
				Changed (this, EventArgs.Empty);
		}

		public event EventHandler Changed;

	}
}
